@@ -80,8 +80,7 @@
 #     set before calling the segmentation method.  The random seed is
 #     set to its original state when exiting.  If @NULL, it is not set.}
 #   \item{verbose}{See @see "R.utils::Verbose".}
-#   \item{preserveScale}{\emph{Deprecated and ignored
-#                        will give a warning if specified.}}
+#   \item{preserveScale}{\emph{Defunct - gives an error is specified.}}
 # }
 #
 # \value{
@@ -312,7 +311,7 @@ setMethodS3("segmentByPairedPSCBS", "default", function(CT, thetaT=NULL, thetaN=
 
   # Argument 'preserveScale' is deprecated
   if (!missing(preserveScale)) {
-    .Deprecated(msg = "Argument 'preserveScale' for segmentByPairedPSCBS() is deprecated and ignored; as of PSCBS 0.64.0 (Mar 2018) it is effectively fixed to FALSE, which has been the default since PSCBS 0.50.0 (Oct 2015). To avoid this warning, do not specify 'preserveScale' when calling segmentByPairedPSCBS().")
+    .Defunct(msg = "Argument 'preserveScale' for segmentByPairedPSCBS() is defunct; as of PSCBS 0.64.0 (Mar 2018) it is effectively fixed to FALSE, which has been the default since PSCBS 0.50.0 (Oct 2015). To avoid this error, do not specify 'preserveScale' when calling segmentByPairedPSCBS().")
   }
   
   verbose && enter(verbose, "Segmenting paired tumor-normal signals using Paired PSCBS")
@@ -1001,8 +1000,8 @@ setMethodS3("segmentByPairedPSCBS", "default", function(CT, thetaT=NULL, thetaN=
       # Sanity check
       .stop_if_not(nrow(tcnSegmentsKK) == nrow(dhSegments))
       .stop_if_not(nrow(tcnSegRowsKK) == nrow(dhSegments))
-      .stop_if_not(is.na(tcnSegRowsKK[,1]) || is.na(dhSegRowsKK[,1]) || (tcnSegRowsKK[,1] <= dhSegRowsKK[,1]))
-      .stop_if_not(is.na(tcnSegRowsKK[,2]) || is.na(dhSegRowsKK[,2]) || (dhSegRowsKK[,2] <= tcnSegRowsKK[,2]))
+      .stop_if_not(all(is.na(tcnSegRowsKK[,1]) | is.na(dhSegRowsKK[,1]) | (tcnSegRowsKK[,1] <= dhSegRowsKK[,1])))
+      .stop_if_not(all(is.na(tcnSegRowsKK[,2]) | is.na(dhSegRowsKK[,2]) | (dhSegRowsKK[,2] <= tcnSegRowsKK[,2])))
       verbose && cat(verbose, "TCN segmentation rows:")
       verbose && print(verbose, tcnSegRowsKK)
       .stop_if_not(all(tcnSegRowsKK[,1] == tcnSegRowsKK[1,1], na.rm=TRUE))
